@@ -4,7 +4,7 @@
 #' together with methods for calculating the hierarchical clusters
 #' provided by a certain distance calculation.
 #' @name cluster
-#' @param object a migraph-consistent object
+#' @param object A migraph-consistent object.
 #' @importFrom stats as.dist hclust
 NULL
 
@@ -14,6 +14,9 @@ NULL
 #' @export
 cluster_structural_equivalence <- function(object){
   mat <- node_tie_census(object)
+  if(any(colSums(t(mat))==0)){
+    mat <- cbind(mat, (colSums(t(mat))==0))
+  } 
   correlations <- cor(t(mat))
   dissimilarity <- 1 - correlations
   distances <- stats::as.dist(dissimilarity)
@@ -24,10 +27,15 @@ cluster_structural_equivalence <- function(object){
 #' @rdname cluster
 #' @examples
 #' ggtree(cluster_regular_equivalence(mpn_elite_mex))
+#' ggtree(cluster_regular_equivalence(mpn_elite_usa_advice))
 #' @export
 cluster_regular_equivalence <- function(object){
-  triads <- node_triad_census(object)
-  triads <- triads[,-which(colSums(triads) == 0)]
+  if(is_twomode(object)){
+    triads <- as.matrix(node_quad_census(object))
+  } else {
+    triads <- node_triad_census(object)
+  }
+  if(any(colSums(triads) == 0)) triads <- triads[,-which(colSums(triads) == 0)]
   correlations <- cor(t(triads))
   dissimilarity <- 1 - correlations
   distances <- stats::as.dist(dissimilarity)
