@@ -9,3 +9,8 @@ test_that("Blau index function works", {
 test_that("EI index function works", {
   expect_equal(round(graph_ei_index(mpn_elite_mex, "military"), 2), -0.37)
 })
+
+test_that("graph_assortativity function works", {
+  expect_length(graph_assortativity(mpn_elite_mex), 1)
+  expect_equal(class(graph_assortativity(mpn_elite_mex)), "numeric")
+})
